# What is the purpose of your *pull request*?

 - [ ] Bug fix
 - [ ] New feature

# Proposed changes


# Warning

Before submitting a *pull request* make sure you have:

 - [ ] Wrote some tests and kept 100% coverage
 - [ ] Ran tox (at minimum for locally available python environment) 
 - [ ] Respected the [PEP 8](https://www.python.org/dev/peps/pep-0008).
 - [ ] Read the guidelines for contributing linked to above.
 - [ ] Put yourself in the contributors file 
